Installation
============

Installation of the ``syglass`` Python module is done via ``pip``, a simple package management system included with
most installations of Python.

Note that you will need Python 3.4 or greater to use the ``syglass`` module.


Installing
------------

Installation is performed using ``pip`` through the command line as follows: ::

	pip install syglass

Updating an existing installation is similar: ::

	pip install syglass --upgrade

Uninstalling
--------------

``pip`` can also be used to uninstall the module once it's been installed: ::

	pip uninstall syglass